==> github-workitem-7.7.0.Final-sources.jar: org/jbpm/process/workitem/github/RepositoryInfo.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jbpm.process.workitem.github;

import org.eclipse.egit.github.core.Repository;

public class RepositoryInfo {

    public long id;
    public String name;
    public String gitURL;
    public String htmlURL;
    public String sshURL;
    public String description;
    public String masterBranch;
    public int openIssues;
    public int watchers;

    public RepositoryInfo(Repository repository) {
        if(repository != null) {
            this.id = repository.getId();
            this.name = repository.getName();
            this.gitURL = repository.getGitUrl();
            this.htmlURL = repository.getHtmlUrl();
            this.description = repository.getDescription();
            this.masterBranch = repository.getMasterBranch();
            this.openIssues = repository.getOpenIssues();
            this.sshURL = repository.getSshUrl();
            this.watchers = repository.getWatchers();
        }
    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getGitURL() {
        return gitURL;
    }

    public void setGitURL(String gitURL) {
        this.gitURL = gitURL;
    }

    public String getHtmlURL() {
        return htmlURL;
    }

    public void setHtmlURL(String htmlURL) {
        this.htmlURL = htmlURL;
    }

    public String getSshURL() {
        return sshURL;
    }

    public void setSshURL(String sshURL) {
        this.sshURL = sshURL;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getMasterBranch() {
        return masterBranch;
    }

    public void setMasterBranch(String masterBranch) {
        this.masterBranch = masterBranch;
    }

    public int getOpenIssues() {
        return openIssues;
    }

    public void setOpenIssues(int openIssues) {
        this.openIssues = openIssues;
    }

    public int getWatchers() {
        return watchers;
    }

    public void setWatchers(int watchers) {
        this.watchers = watchers;
    }
}

==> github-workitem-7.73.0.Final-sources.jar: org/jbpm/process/workitem/github/RepositoryInfo.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jbpm.process.workitem.github;

import java.io.Serializable;

import org.eclipse.egit.github.core.Repository;

public class RepositoryInfo implements Serializable {

    public long id;
    public String name;
    public String gitURL;
    public String htmlURL;
    public String sshURL;
    public String description;
    public String masterBranch;
    public int openIssues;
    public int watchers;

    public RepositoryInfo(Repository repository) {
        if (repository != null) {
            this.id = repository.getId();
            this.name = repository.getName();
            this.gitURL = repository.getGitUrl();
            this.htmlURL = repository.getHtmlUrl();
            this.description = repository.getDescription();
            this.masterBranch = repository.getMasterBranch();
            this.openIssues = repository.getOpenIssues();
            this.sshURL = repository.getSshUrl();
            this.watchers = repository.getWatchers();
        }
    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getGitURL() {
        return gitURL;
    }

    public void setGitURL(String gitURL) {
        this.gitURL = gitURL;
    }

    public String getHtmlURL() {
        return htmlURL;
    }

    public void setHtmlURL(String htmlURL) {
        this.htmlURL = htmlURL;
    }

    public String getSshURL() {
        return sshURL;
    }

    public void setSshURL(String sshURL) {
        this.sshURL = sshURL;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getMasterBranch() {
        return masterBranch;
    }

    public void setMasterBranch(String masterBranch) {
        this.masterBranch = masterBranch;
    }

    public int getOpenIssues() {
        return openIssues;
    }

    public void setOpenIssues(int openIssues) {
        this.openIssues = openIssues;
    }

    public int getWatchers() {
        return watchers;
    }

    public void setWatchers(int watchers) {
        this.watchers = watchers;
    }
}
